@@ -4,7 +4,7 @@
 #
 #       AUTHOR:  Aliaksandr P. Zahatski, <zahatski@gmail.com>
 #===============================================================================
-#$Id$
+#$Id: Parser.pm 587 2009-08-11 03:13:15Z zag $
 package CustomBlock;
 use strict;
 use warnings;
@@ -25,7 +25,7 @@ use strict;
 use warnings;
 use Test::More;
 use Perl6::Pod::FormattingCode;
-use base 'Perl6::Pod::Block';
+use base 'Perl6::Pod::FormattingCode';
 
 sub on_para {
     my ( $self, $p, $txt ) = @_;
@@ -67,13 +67,13 @@ sub p01_custom_code_on_para : Test {
     my $t = shift;
     my $x = $t->parse_to_xml( <<T, 'Perl6::Pod::Parser::CustomCodes' );
 =begin pod
-=use CustomFormattingCode Tcustom
+=use CustomFormattingCode Tcustom<>
 M<Tcustom:some text>
 =end pod
 T
     $t->is_deeply_xml(
         $x,
-q# <pod pod:type='block' xmlns:pod='http://perlcabal.org/syn/S26.html'><para pod:type='block'><Tcustom pod:type='block' pod:on_para='1'>some text</Tcustom>
+q# <pod pod:type='block' xmlns:pod='http://perlcabal.org/syn/S26.html'><para pod:type='block'><Tcustom pod:type='code' pod:on_para='1'>some text</Tcustom>
  </para></pod>#
     );
 }
@@ -124,7 +124,7 @@ q#<pod pod:type='block' xmlns:pod='http://perlcabal.org/syn/S26.html'><ParsePara
     );
 }
 
-sub p04_process_para : Test(2) {
+sub p04_process_para : Test(2){
     my $t         = shift;
     my $out       = '';
     my $to_parser = new Perl6::Pod::To::XML:: out_put => \$out;
@@ -133,27 +133,28 @@ sub p04_process_para : Test(2) {
 test S<L<k>>
 T
     my $ref1 = $p->parse_para($txt);
-    is_deeply $ref1, [
-        {
+    is_deeply $ref1,[
+          {
             'type' => 'para',
             'data' => 'test '
-        },
-        {
-            'name'   => 'S',
+          },
+          {
+            'name' => 'S',
             'childs' => [
-                {
-                    'name'   => 'L',
-                    'childs' => [ 'k' ]
-                }
-            ]
-        },
-        {
+                          {
+                            'name' => 'L',
+                            'childs' => [
+                                          'k'
+                                        ]
+                          }
+                        ]
+          },
+          {
             'type' => 'para',
             'data' => '
 '
-        }
-      ],
-      'check stuct';
+          }
+        ], 'check stuct';
     is_deeply $ref1, $p->parse_para($ref1), 'duble pass';
 }
 
@@ -168,47 +169,46 @@ S<L<k>>test
 T
     my $ref = $p->parse_para($txt);
     is_deeply $ref, [
-        {
-            'name'   => 'S',
+          {
+            'name' => 'S',
             'childs' => [
-                {
-                    'name'   => 'L',
-                    'childs' => [ 'k' ]
-                }
-            ]
-        },
-        {
+                          {
+                            'name' => 'L',
+                            'childs' => [
+                                          'k'
+                                        ]
+                          }
+                        ]
+          },
+          {
             'type' => 'para',
             'data' => 'test
 '
-        }
-      ],
-      'check parse_para for S<L<k>>test';
+          }
+        ], 'check parse_para for S<L<k>>test';
 
-    is_deeply [ $p->__make_events( $ref->[0] ) ],
-      [
-        {
+    is_deeply [ $p->__make_events($ref->[0]) ], [
+          {
             'data' => 'S',
             'type' => 'start_fcode'
-        },
-        {
+          },
+          {
             'data' => 'L',
             'type' => 'start_fcode'
-        },
-        {
+          },
+          {
             'data' => 'k',
             'type' => 'para'
-        },
-        {
+          },
+          {
             'data' => 'L',
             'type' => 'end_fcode'
-        },
-        {
+          },
+          {
             'data' => 'S',
             'type' => 'end_fcode'
-        }
-      ],
-      '__make_events for element';
+          }
+        ], '__make_events for element';
     $p->begin_input;
     $p->start_block( 'pod',,  0 );
     $p->start_block( 'para',, 0 );
@@ -216,11 +216,8 @@ T
     $p->end_block( 'para',, 0 );
     $p->end_block( 'pod',,  0 );
     $p->end_input;
-    $t->is_deeply_xml(
-        $out,
-q#<pod pod:type='block' xmlns:pod='http://perlcabal.org/syn/S26.html'><para pod:type='block'><S pod:type='code'><L pod:section='' pod:type='code' pod:scheme='' pod:is_external='' pod:name='' pod:address=''>k</L></S>test
- </para></pod>#
-    );
+$t->is_deeply_xml ( $out, q#<pod pod:type='block' xmlns:pod='http://perlcabal.org/syn/S26.html'><para pod:type='block'><S pod:type='code'><L pod:type='code'>k</L></S>test
+ </para></pod>#);
 }
 
 1;
